@@ -169,11 +169,14 @@ def cli():
       _diagnostics()
       return 0
 
-   try:
+   if options.stacktrace:
       logfile = setupLogging(options)
-   except Exception as e:
-      sys.stderr.write("Error setting up logging: %s\n" % e)
-      return 3
+   else:
+      try:
+         logfile = setupLogging(options)
+      except Exception as e:
+         sys.stderr.write("Error setting up logging: %s\n" % e)
+         return 3
 
    logger.info("Cedar Backup 'span' utility run started.")
    logger.info("Options were [%s]", options)
@@ -295,6 +298,7 @@ def _diagnostics(fd=sys.stdout):
 # _executeAction() function
 ############################
 
+# pylint: disable=W0613
 def _executeAction(options, config):
    """
    Implements the guts of the cback3-span tool.
@@ -545,6 +549,7 @@ def _discInitializeImage(config, writer, spanItem):
          print("===")
    print("Completed initializing image.")
 
+# pylint: disable=W0613
 def _discWriteImage(config, writer):
    """
    Writes a ISO image for a span item.
